@@ -12,6 +12,8 @@ def read_hosts(pathnames, default_user=None, default_port=None):
     ssh, etc.)
     """
     lines = []
+    if not pathnames:
+        return lines
     for pathname in pathnames:
         f = open(pathname)
         for line in f:
@@ -29,7 +31,7 @@ def read_hosts(pathnames, default_user=None, default_port=None):
         elif len(fields) == 2:
             addr, user = fields
         else:
-            print "Bad line. Must be host[:port] [login]"
+            sys.stderr.write("Bad line. Must be host[:port] [login]\n")
             sys.exit(3)
         addr_fields = addr.split(':')
         if len(addr_fields) == 1:
@@ -38,8 +40,18 @@ def read_hosts(pathnames, default_user=None, default_port=None):
         elif len(addr_fields) == 2:
             host, port = addr_fields
         else:
-            print "Bad line. Must be host[:port] [login]"
+            sys.stderr.write("Bad line. Must be host[:port] [login]\n")
             sys.exit(3)
         hosts.append((host, port, user))
     return hosts
 
+def parse_host(host, default_user=None, default_port=None):
+    """Parses host entries of the form "[user@]host[:port]"."""
+    # TODO: when we stop supporting Python 2.4, switch to using str.partition.
+    user = default_user
+    port = default_port
+    if '@' in host:
+        user, host = host.split('@', 1)
+    if ':' in host:
+        host, port = host.rsplit(':', 1)
+    return (host, port, user)
